@@ -1,6 +1,6 @@
 #include <cstring>
 
-#include <S.h>
+#include "verS.h"
 #ifdef USING_R
 #include <R.h>
 #include <Rinternals.h>
