@@ -1,7 +1,7 @@
 #ifndef MULTIC_STRING_H
 #define MULTIC_STRING_H
 
-#include <S.h>
+#include "verS.h"
 #ifdef USING_R
 #include <R.h>
 #include <Rinternals.h>
